import React from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleOrdinal, max, format, extent } from 'd3';
import * as d3 from 'd3';

const App = () => {
  
  let width = 450;
	let height = 450;
  let margin = 40;

// The radius of the pieplot is half the width or half the height (smallest one). I subtract a bit of margin.
	let radius = Math.min(width, height) / 2 - margin;

// append the svg object to the div called 'root'
	let svg = d3.select("#root")
    .append("svg")
      .attr("width", width)
      .attr("height", height)
    .append("g")
      .attr("transform", "translate(" + width / 2 + "," + height / 2 + ")");

  // Create dummy data
  let data = {a: 9, b: 20, c:30, d:8, e:12};

  // set the color scale
  var color = d3.scaleOrdinal()
    .domain(data)
    .range(["#98abc5", "#8a89a6", "#7b6888", "#6b486b", "#a05d56"]);

  // Compute the position of each group on the pie:
  var pie = d3.pie()
    .value(function(d) {return d.value; })
  var data_ready = pie(d3.entries(data));

  // Build the pie chart: Basically, each part of the pie is a path that we build using the arc function.
  return svg
    .selectAll('whatever')
    .data(data_ready)
    .enter()
    .append('path')
    .attr('d', d3.arc()
      .innerRadius(100)         // This is the size of the donut hole
      .outerRadius(radius)
    )
    .attr('fill', function(d){ return(color(d.data.key)) });

};

ReactDOM.render(<App />, document.getElementById('root'));
